@@ -3,23 +3,24 @@ package Business::CyberSource::Report;
 use strict;
 use warnings;
 
-use Carp;
-use Class::Load qw();
-use Storable qw();
+use XML::LibXML qw();
+use LWP::UserAgent qw();
+use HTTP::Request qw();
 
 
 =head1 NAME
 
-Business::CyberSource::Report - Factory class for modules that retrieve CyberSource's XML reports.
+Business::CyberSource::Report - The factory class for modules that retrieve
+CyberSource's XML reports.
 
 
 =head1 VERSION
 
-Version 1.2.0
+Version 1.1
 
 =cut
 
-our $VERSION = '1.2.0';
+our $VERSION = '1.1';
 
 our $LOADED_REPORT_MODULES;
 
@@ -28,7 +29,7 @@ our $LOADED_REPORT_MODULES;
 
 	use Business::CyberSource::Report;
 	use Business::CyberSource::Report::Test;
-
+	
 	# Generate a report factory.
 	my $report_factory = Business::CyberSource::Report->new(
 		merchant_id           => $merchant_id,
@@ -36,11 +37,11 @@ our $LOADED_REPORT_MODULES;
 		password              => $password,
 		use_production_system => $use_production_system,
 	);
-
+	
 	# Use the factory to get a Business::CyberSource::Report::Test object with
 	# the correct connection parameters.
 	my $test_report = $report_factory->build( 'test' );
-
+	
 	# Retrieve a list of the report modules that have been loaded in memory,
 	# either via "use" or a require by build()
 	my $available_reports = $report_factory->list_loaded();
@@ -85,22 +86,22 @@ system (1) or the test system (0). Off by default.
 sub new
 {
 	my ( $class, %args ) = @_;
-
+	
 	# Check for required arguments.
 	foreach my $arg ( qw( merchant_id password ) )
 	{
-		croak "The parameter >$arg< is missing"
-			if !defined( $args{ $arg } ) || ( $args{ $arg } eq '' );
+		die "The parameter >$arg< is missing"
+			unless defined( $args{ $arg } ) && ( $args{ $arg } ne '' );
 	}
-
+	
 	# By default per CyberSource's interface, the username is the merchant ID.
 	$args{'username'} = $args{'merchant_id'}
 		unless defined( $args{'username'} );
-
+	
 	# By default, use the test environment.
 	$args{'use_production_system'} = 0
 		unless defined( $args{'use_production_system'} );
-
+	
 	# Build the object, blessed with the child's class to simplify new() in
 	# children classes.
 	my $self = bless(
@@ -110,7 +111,7 @@ sub new
 		},
 		$class,
 	);
-
+	
 	return $self;
 }
 
@@ -124,24 +125,24 @@ dynamically when calling build().
 
 =cut
 
-sub list_loaded
+sub list_loaded()
 {
 	my ( $self ) = @_;
-
+	
 	if ( !defined( $LOADED_REPORT_MODULES ) )
 	{
 		$LOADED_REPORT_MODULES = {};
-
+		
 		my $main_module_path = __PACKAGE__;
 		$main_module_path =~ s/::/\//g;
-
+		
 		foreach my $module ( keys %INC )
 		{
 			next unless $module =~ m/^\Q$main_module_path\/\E([^\/]+)\.pm/;
 			$LOADED_REPORT_MODULES->{ $1 } = undef;
 		}
 	}
-
+	
 	return [ keys %$LOADED_REPORT_MODULES ];
 }
 
@@ -171,29 +172,31 @@ Business::CyberSource::Report::SingleTransaction.
 sub build
 {
 	my ( $self, $module ) = @_;
-
-	croak 'Please specify the name of the module to build'
-		if !defined( $module ) || ( $module eq '' );
-
+	
+	die 'Please specify the name of the module to build'
+		unless defined( $module ) && ( $module ne '' );
+	
 	my $class = __PACKAGE__ . '::' . $module;
-
+	
 	# If the module isn't already loaded, do that now.
 	if ( scalar( grep { $module eq $_ } @{ $self->list_loaded() || [] } ) == 0 )
 	{
-		Class::Load::load_optional_class( $class ) || croak "Failed to load $class, double-check the class name";
+		eval "use $class; 1;" || die "Failed to load $class, double-check the class name";
 		$LOADED_REPORT_MODULES->{ $module } = undef;
 	}
-
+	
 	my $object = bless(
-		# Create a copy of the factory's guts, the object will be a subclass of
-		# the factory and will be able to use all the information.
-		# Also, we don't want a change in the factory parameters to cascade to
-		# the objects previously built, so it makes sense to copy.
-		# TBD: copy only a selected subset of the content?
-		Storable::dclone( $self ),
+		{
+			# Create a copy of the factory's guts, the object will be a subclass of
+			# the factory and will be able to use all the information.
+			# Also, we don't want a change in the factory parameters to cascade to
+			# the objects previously built, so it makes sense to copy.
+			# TBD: copy only a selected subset of the content?
+			%$self,
+		},
 		$class,
 	);
-
+	
 	return $object;
 }
 
@@ -211,7 +214,7 @@ Return the username to use to connect to the service.
 sub get_username
 {
 	my ( $self ) = @_;
-
+	
 	return $self->{'username'};
 }
 
@@ -227,7 +230,7 @@ Return the password to use to connect to the service.
 sub get_password
 {
 	my ( $self ) = @_;
-
+	
 	return $self->{'password'};
 }
 
@@ -243,7 +246,7 @@ Return the merchant ID to use to connect to the service.
 sub get_merchant_id
 {
 	my ( $self ) = @_;
-
+	
 	return $self->{'merchant_id'};
 }
 
@@ -260,24 +263,28 @@ Otherwise, the Test Business Center is used.
 sub use_production_system
 {
 	my ( $self ) = @_;
-
+	
 	return $self->{'use_production_system'} ? 1 : 0;
 }
 
 
+=head1 AUTHOR
+
+Guillaume Aubert, C<< <aubertg at cpan.org> >>.
+
+
 =head1 BUGS
 
-Please report any bugs or feature requests through the web interface at
-L<https://github.com/guillaumeaubert/Business-CyberSource-Report/issues/new>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+Please report any bugs or feature requests to C<bug-business-cybersource-report at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=business-cybersource-report>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
 
 
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
-	perldoc Business::CyberSource::Report
+	perldoc Business::CyberSource::Reporting::XML
 
 
 You can also look for information at:
@@ -286,9 +293,9 @@ You can also look for information at:
 
 =item *
 
-GitHub's request tracker
+RT: CPAN's request tracker
 
-L<https://github.com/guillaumeaubert/Business-CyberSource-Report/issues>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=business-cybersource-report>
 
 =item *
 
@@ -304,34 +311,26 @@ L<http://cpanratings.perl.org/d/business-cybersource-report>
 
 =item *
 
-MetaCPAN
+Search CPAN
 
-L<https://metacpan.org/release/Business-CyberSource-Report>
+L<http://search.cpan.org/dist/business-cybersource-report/>
 
 =back
 
 
-=head1 AUTHOR
-
-L<Guillaume Aubert|https://metacpan.org/author/AUBERTG>, C<< <aubertg at cpan.org> >>.
-
-
 =head1 ACKNOWLEDGEMENTS
 
-I originally developed this project for ThinkGeek
-(L<http://www.thinkgeek.com/>). Thanks for allowing me to open-source it!
+Thanks to Geeknet, Inc. L<http://www.geek.net> for funding the initial development of this code!
 
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2011-2017 Guillaume Aubert.
+Copyright 2011 Guillaume Aubert.
 
-This code is free software; you can redistribute it and/or modify it under the
-same terms as Perl 5 itself.
+This program is free software; you can redistribute it and/or modify it
+under the terms of the Artistic License.
 
-This program is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE. See the LICENSE file for more details.
+See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
