@@ -5,23 +5,23 @@ use warnings;
 
 use base 'Business::CyberSource::Report';
 
-use Carp;
 use HTTP::Request::Common qw();
 use LWP::UserAgent qw();
 
 
 =head1 NAME
 
-Business::CyberSource::Report::PaymentEvents - Interface to CyberSource's Payment Events report.
+Business::CyberSource::Report::PaymentEvents - Interface to CyberSource's
+Payment Events report.
 
 
 =head1 VERSION
 
-Version 1.2.0
+Version 1.0
 
 =cut
 
-our $VERSION = '1.2.0';
+our $VERSION = '1.0';
 
 our $TEST_URL = 'https://ebctest.cybersource.com/ebctest';
 our $PRODUCTION_URL = 'https://ebc.cybersource.com/ebc';
@@ -32,17 +32,17 @@ our $PRODUCTION_URL = 'https://ebc.cybersource.com/ebc';
 This module is an interface to the Payment Events report from CyberSource.
 
 	use Business::CyberSource::Report;
-
+	
 	# Generate a report factory.
 	my $report_factory = Business::CyberSource::Report->new(
 		merchant_id => $merchant_id,
 		username    => $username,
 		password    => $password,
 	);
-
+	
 	# Build a Business::CyberSource::Report::PaymentEvents object.
 	my $payment_events_report = $report_factory->build( 'PaymentEvents' );
-
+	
 	# Retrieve the Payment Events report for a given date.
 	$payment_events_report->retrieve(
 		format => $format,
@@ -66,19 +66,13 @@ Parameters:
 
 =over
 
-=item * format (mandatory)
+=item *
 
-The desired format of the report, 'csv' or 'xml'.
+format: the desired format of the report, 'csv' or 'xml'.
 
-=item * date (mandatory)
+=item *
 
-The date of the transactions to include in the report, using the format
-YYYY/MM/DD.
-
-=item * user_agent (optional)
-
-By default, C<LWP::UserAgent>. This is useful for tests, see the documentation
-for L<Test::LWP::UserAgent> in particular.
+date: the date of the transactions to include in the report, using the format YYYY/MM/DD.
 
 =back
 
@@ -89,53 +83,57 @@ sub retrieve
 	my ( $self, %args ) = @_;
 	my $format = delete( $args{'format'} );
 	my $date = delete( $args{'date'} );
-	my $user_agent = delete( $args{'user_agent'} ) || LWP::UserAgent->new();
-
+	
 	# Verify the format.
-	croak "The format needs to be 'csv' or 'xml'"
+	die "The format needs to be 'csv' or 'xml'"
 		unless defined( $format ) && ( $format =~ m/^(csv|xml)$/ );
-
+	
 	# Verify the date.
-	croak 'You need to specify a date for the transactions to retrieve'
+	die 'You need to specify a date for the transactions to retrieve'
 		unless defined( $date );
-	croak 'The format for the date of the transactions to retrieve is YYYY/MM/DD'
+	die 'The format for the date of the transactions to retrieve is YYYY/MM/DD'
 		unless $date =~ m/^\d{4}\/\d{2}\/\d{2}$/;
-
+	
 	# Prepare the URL to hit.
 	my $url = ( $self->use_production_system() ? $PRODUCTION_URL : $TEST_URL )
 		. '/DownloadReport/' . $date . '/' . $self->get_merchant_id()
 		. '/PaymentEventsReport.' . $format;
-
+	
 	# Send the query.
+	my $user_agent = LWP::UserAgent->new();
 	my $request = HTTP::Request::Common::GET( $url );
 	$request->authorization_basic(
 		$self->get_username(),
 		$self->get_password(),
 	);
-
+	
 	my $response = $user_agent->request( $request );
-	croak "Could not get a response from CyberSource"
+	die "Could not get a response from CyberSource"
 		unless defined $response;
-	croak "CyberSource returned the following error: " . $response->status_line()
+	die "CyberSource returned the following error: " . $response->status_line()
 		unless $response->is_success();
-
+	
 	return $response->content();
 }
 
 
+=head1 AUTHOR
+
+Guillaume Aubert, C<< <aubertg at cpan.org> >>.
+
+
 =head1 BUGS
 
-Please report any bugs or feature requests through the web interface at
-L<https://github.com/guillaumeaubert/Business-CyberSource-Report/issues/new>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+Please report any bugs or feature requests to C<bug-business-cybersource-report-paymentevents at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=business-cybersource-report-paymentevents>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
 
 
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
-	perldoc Business::CyberSource::Report::PaymentEvents
+	perldoc Business::CyberSource::Reporting::XML::PaymentEvents
 
 
 You can also look for information at:
@@ -144,52 +142,44 @@ You can also look for information at:
 
 =item *
 
-GitHub's request tracker
+RT: CPAN's request tracker
 
-L<https://github.com/guillaumeaubert/Business-CyberSource-Report/issues>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=business-cybersource-report-paymentevents>
 
 =item *
 
 AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/dist/business-cybersource-report>
+L<http://annocpan.org/dist/business-cybersource-report-paymentevents>
 
 =item *
 
 CPAN Ratings
 
-L<http://cpanratings.perl.org/d/business-cybersource-report>
+L<http://cpanratings.perl.org/d/business-cybersource-report-paymentevents>
 
 =item *
 
-MetaCPAN
+Search CPAN
 
-L<https://metacpan.org/release/Business-CyberSource-Report>
+L<http://search.cpan.org/dist/business-cybersource-report-paymentevents/>
 
 =back
 
 
-=head1 AUTHOR
-
-L<Guillaume Aubert|https://metacpan.org/author/AUBERTG>, C<< <aubertg at cpan.org> >>.
-
-
 =head1 ACKNOWLEDGEMENTS
 
-I originally developed this project for ThinkGeek
-(L<http://www.thinkgeek.com/>). Thanks for allowing me to open-source it!
+Thanks to Geeknet, Inc. L<http://www.geek.net> for funding the initial development of this code!
 
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2011-2017 Guillaume Aubert.
+Copyright 2011 Guillaume Aubert.
 
-This code is free software; you can redistribute it and/or modify it under the
-same terms as Perl 5 itself.
+This program is free software; you can redistribute it and/or modify it
+under the terms of the Artistic License.
 
-This program is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE. See the LICENSE file for more details.
+See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
